Implementation of Narrowest Significance Pursuit (NSP), a general and
flexible methodology for automatically detecting localised regions in data sequences
which each must contain a change-point (understood as an abrupt change in the
parameters of an underlying linear model), at a prescribed global significance level.
NSP works with a wide range of distributional assumptions on the errors, and yields
exact desired finite-sample coverage probabilities, regardless of the form or number
of the regressors. A good place to start exploring the package are the nsp* functions.
P. Fryzlewicz (2021) "Narrowest Significance Pursuit: inference for multiple change-points in linear models", preprint.
nsp, nsp_poly, nsp_poly_ar, nsp_tvreg, nsp_selfnorm,
nsp_poly_selfnorm