thresh_kab: Compute the theoretical threshold for the multiscale sup-norm...

Description Usage Arguments Details Value Author(s) See Also Examples

View source: R/thresh_kab.R

Description

This function computes the theoretical threshold, corresponding to the given significance level alpha, for the multiscale sup-norm if the underlying distribution is standard normal.

Usage

1
thresh_kab(n, alpha = 0.1, method = "asymp")

Arguments

n

The sample size.

alpha

The significance level.

method

"asymp" for the asymptotic method; "bound" for the Bonferroni method.

Details

For the underlying theory, see Z. Kabluchko (2007) Extreme-value analysis of standardized Gaussian increments. Unpublished.

Value

The desired threshold.

Author(s)

Piotr Fryzlewicz, p.fryzlewicz@lse.ac.uk

See Also

cov_dep_multi_norm, cov_dep_multi_norm_poly, sim_max_holder

Examples

1
2
3
4
5
6
7
set.seed(1)
f <- c(1:100, 100:1, 1:100)
y <- f + stats::rnorm(300) * 15
x <- matrix(0, 300, 2)
x[,1] <- 1
x[,2] <- seq(from = 0, to = 1, length = 300)
nsp(y, x, 100, 15 * thresh_kab(300, .1))

nsp documentation built on Dec. 21, 2021, 9:07 a.m.