This function produces a change-point prominence plot based on the NSP object provided. The heights of the bars are arranged in non-decreasing
order and correspond directly to the lengths of the NSP intervals of significance. Each bar is labelled as s-e where s (e) is the start (end) of the
corresponding NSP interval of significance, respectively. The change-points corresponding to the narrower intervals can be seen as more prominent.
Usage
cpt_importance(nsp.obj)
Arguments
nsp.obj
Object returned by one of the nsp* functions.
Value
The function does not return a value.
Details
The NSP algorithm is described in P. Fryzlewicz (2021) "Narrowest Significance Pursuit: inference for multiple change-points in linear
models", preprint.