Description Usage Arguments Details Value Author(s) See Also Examples
This function computes the theoretical threshold, corresponding to the given significance level alpha, for the multiscale sup-norm
if the underlying distribution is standard normal.
1 | thresh_kab(n, alpha = 0.1, method = "asymp")
|
n |
The sample size. |
alpha |
The significance level. |
method |
"asymp" for the asymptotic method; "bound" for the Bonferroni method. |
For the underlying theory, see Z. Kabluchko (2007) Extreme-value analysis of standardized Gaussian increments. Unpublished.
The desired threshold.
Piotr Fryzlewicz, p.fryzlewicz@lse.ac.uk
cov_dep_multi_norm, cov_dep_multi_norm_poly, sim_max_holder
1 2 3 4 5 6 7 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.